@@ -1,4 +1,4 @@
-sim.hmm <- function(nsim,tpm,Rho,nrep=1) {
+sim.hmm <- function(nsim,tpm,Rho,ispd=NULL,yval=NULL) {
 #
 # Function sim.hmm to simulate data from a hidden Markov
 # model with transition probability matrix tpm, and discrete
@@ -12,35 +12,47 @@ xxx <- apply(Rho,2,sum)
 if(!identical(all.equal(xxx,rep(1,ncol(Rho))),TRUE))
 	stop("Columns of Rho do not all sum to 1.\n")
 
+# Check for validity of yval argument:
+if(is.null(yval)) {
+	yval <- 1:nrow(Rho)
+} else {
+	if(length(yval)!=nrow(Rho))
+		stop(paste("Mismatch between length of \"yval\"",
+                           "and number of rows of \"Rho\".\n"))
+}
+row.names(Rho) <- yval
+nseq <- length(nsim)
+
 # If Rho has a single column, generate i.i.d. data.
 if(ncol(Rho)==1) {
-	temp <- sample(1:nrow(Rho),size=nsim*nrep,
-                       prob=Rho[,1],replace=TRUE)
-	return(if(nrep==1) temp else matrix(temp,ncol=nrep))
+	temp <- lapply(nsim,function(n,yval,Rho){
+				sample(yval,size=n,prob=Rho[,1],replace=TRUE)
+                            },yval=yval,Rho=Rho)
+	return(if(nseq==1) temp[[1]] else temp)
 }
 
 if(ncol(tpm) != nrow(tpm))
 	stop("The matrix tpm must be square.\n")
 if(ncol(tpm) != ncol(Rho))
-	stop("Mismatch in dimensions of tpm and Rho.\n")
+	stop("Mismatch between dimensions of tpm and Rho.\n")
 if(any(tpm<0)) stop("Negative entries in tpm.\n")
 xxx <- apply(tpm,1,sum)
 if(!identical(all.equal(xxx,rep(1,nrow(tpm))),TRUE))
 	stop("Rows of tpm do not all sum to 1.\n")
 
-ispd <- revise.ispd(tpm)
+if(is.null(ispd)) ispd <- revise.ispd(tpm)
 K    <- ncol(Rho)
 M    <- nrow(Rho)
 rslt <- list()
-for(j in 1:nrep) {
+for(j in 1:nseq) {
 	s1     <- sample(1:K,1,prob=ispd)
 	y      <- list()
-	y[[1]] <- sample(1:M,1,prob=Rho[,s1])
-	for(i in 2:nsim) {
+	y[[1]] <- sample(yval,1,prob=Rho[,s1])
+	for(i in 2:nsim[j]) {
 		s1 <- sample(1:K,1,prob=tpm[s1,])
-		y[[i]] <- sample(1:M,1,prob=Rho[,s1])
+		y[[i]] <- sample(yval,1,prob=Rho[,s1])
 	}
 	rslt[[j]] <- unlist(y)
 }
-if(nrep>1) matrix(unlist(rslt),ncol=nrep) else unlist(rslt)
+if(nseq==1) rslt[[1]] else rslt 
 }
